<?php

namespace plugin\inspection\controller\api\auth;

use plugin\inspection\controller\api\Auth;
use plugin\inspection\model\InspectionRecord;
use plugin\ticket\model\TicketTicket;

class Record extends Auth
{
    public function index()
    {
        $pageData = $this->staff->records()->order('create_at desc')->paginate();
        $this->success('获取记录成功', $pageData);
    }

    public function info()
    {
        $record_id = $this->request->get('record_id');
        $record = InspectionRecord::mk()->where('id', $record_id)->with(['points'])->find();
        if (empty($record)) {
            $this->error('记录不存在');
        }
        $this->success('获取记录成功', $record);
    }

    public function create()
    {
        $record = $this->staff->records()->save([
            'no' => uniqid('XJ_' . date('YmdHis')),
            'create_at' => date('Y-m-d H:i:s'),
            'status' => 0,
        ]);
        $this->success('创建记录成功', $record);
    }

    public function end()
    {
        $record_id = $this->request->post('record_id');
        $record = InspectionRecord::mk()->where('id', $record_id)->find();
        if (empty($record)) {
            $this->error('记录不存在');
        }
        $lat = $this->request->post('lat');
        $lng = $this->request->post('lng');
        $imgs = $this->request->post('imgs');
        $content = $this->request->post('content');
        $record->status = 1;
        $record->imgs = $imgs;
        $record->content = $content;
        $record->points()->save([
            'staff_id' => $this->staff->id,
            'lat' => $lat,
            'lng' => $lng,
            'is_pause' => 1,
            'create_at' => date('Y-m-d H:i:s'),
        ]);
        $record->save();
        $record->autoFix();
        $this->success('结束记录成功');
    }

    public function add_point()
    {
        $record_id = $this->request->post('record_id');
        $lat = $this->request->post('lat');
        $lng = $this->request->post('lng');
        /** @var InspectionRecord $record */
        $record = InspectionRecord::query()->where('id', $record_id)->find();
        if (empty($record)) {
            $this->error('记录不存在');
        }
        $point = $record->points()->save([
            'staff_id' => $this->staff->id,
            'is_pause' => $this->request->post('is_pause', 0),
            'lat' => $lat,
            'lng' => $lng,
            'create_at' => date('Y-m-d H:i:s'),
        ]);
        $record->autoFix();
        $record->save();
        $this->success('添加点成功', $point);
    }

    public function update_point()
    {
        $record_id = $this->request->post('record_id');
        $point_id = $this->request->post('id');
        /** @var InspectionRecord $record */
        $record = InspectionRecord::query()->where('id', $record_id)->find();
        if (empty($record)) {
            $this->error('记录不存在');
        }
        $point = $record->points()->where('id', $point_id)->find();
        if (empty($point)) {
            $this->error('点不存在');
        }
        $point->is_pause = $this->request->post('is_pause', 0);
        $point->save();
        $this->success("成功");
    }

}