<?php

namespace plugin\ticket\controller;

use plugin\inspection\model\InspectionStaff;
use plugin\ticket\model\TicketDept;
use plugin\ticket\model\TicketReply;
use plugin\ticket\model\TicketTicket;
use plugin\ticket\model\TicketType;
use think\admin\Controller;
use think\admin\helper\QueryHelper;
use think\admin\model\SystemUser;

/**
 * 工单管理
 */
class Ticket extends Controller
{
    /**
     * 工单列表
     * @auth true
     * @menu true
     * @return void
     * @throws \think\db\exception\DataNotFoundException
     * @throws \think\db\exception\DbException
     * @throws \think\db\exception\ModelNotFoundException
     */
    public function index()
    {
        $this->title = '工单中心';
        $this->type_list = TicketType::getList();
        $this->user_id = $this->request->session('user')['id'];
        TicketTicket::mQuery()->layTable(function () {

        }, function (QueryHelper $query) {
            $query->like(['title|content|contact_name|ticket_address|contact_phone#keyword'])
                ->dateBetween(['create_at'])
                ->equal(['status', 'type_id']);
            $query->append(['imgs_arr', 'source_type_name', 'status_text', 'type_name', 'last_reply']);
        });
    }

    /**
     * 添加工单
     * @auth true
     * @menu true
     * @return void
     * @throws \think\db\exception\DataNotFoundException
     * @throws \think\db\exception\DbException
     * @throws \think\db\exception\ModelNotFoundException
     */
    public function add()
    {
        $this->title = '添加工单';
        $this->types = TicketType::mk()->scope('active')->select();
        TicketTicket::mForm('form');
    }

    public function _form_filter(&$data)
    {
        if ($this->request->isPost()) {
            $data['user_id'] = 0;
        }
        $data['status'] = 0;
    }

    /**
     * 查看工单
     * @auth true
     * @menu true
     * @return void
     */
    public function detail()
    {
        $this->title = '工单详情';
        ['id' => $id] = $this->_vali(['id.require' => '请指定工单ID！']);
        $this->vo = TicketTicket::mk()->with(['user', 'type', 'reply'])->append(['imgs_arr', 'status_text', 'type_name', 'last_reply'])->find($id);
        $this->fetch();
    }

    /**
     * 编辑工单
     * @auth true
     * @menu true
     * @return void
     * @throws \think\db\exception\DataNotFoundException
     * @throws \think\db\exception\DbException
     * @throws \think\db\exception\ModelNotFoundException
     */
    public function edit()
    {
        $this->title = '编辑工单';
        $this->types = TicketType::mk()->scope('active')->select();
        TicketTicket::mForm('form');
    }

    /**
     * 删除工单
     * @auth true
     * @menu true
     * @return void
     */
    public function remove()
    {
        TicketTicket::mDelete();
    }

    public function reply()
    {
        $this->title = '回复工单';
        [
            'ticket_id'=>$ticket_id,
            'id'=>$id
        ] = $this->_vali([
            'ticket_id.require'=>'请指定工单ID！',
            'id.require'=>'请指定回复ID！'
        ]);
        $this->vo = TicketTicket::mk()->with(['user', 'type'])->append(['imgs_arr', 'status_text', 'type_name'])->find($ticket_id);
        TicketReply::mForm('reply');
    }

    public function _reply_form_filter(&$data)
    {
        if ($this->request->isPost()) {
            $this->_applyFormToken();
            $data['type'] = 1;
            $adminInfo = $this->request->session('user');
            $data['user_id'] = $adminInfo['id'];
            $data['username'] = $adminInfo['nickname'];
            $data['contact'] = $adminInfo['contact_phone'];
        }
    }

    public function move()
    {
        $this->title = "工单分配";
        if ($this->request->isPost()) {
            $this->_applyFormToken();
            // 提交
            $data = $this->_vali([
                'id.require' => '请指定工单ID！',
                'type.require' => '请指定分配类型！',
                'dept_id.require' => '请指定处理部门！',
                'user_id.default' => '0',
            ]);
            $ticket = TicketTicket::mk()->where('id', '=', $data['id'])->findOrEmpty();
            if ($ticket->isEmpty()) $this->error('工单不存在！');
            $ticket->fz_user_id = $data['user_id'];
            $ticket->fz_dept_id = $data['dept_id'];
            if ($data['type'] == 1) {
                // 内部
                $ticket->state = 1;
            } else {
                // 外部
                $ticket->state = 2;
            }
            $ticket->save();
            $this->success('工单分配成功！');
        } else {
            $this->dept_list = TicketDept::query()->scope('avail')->select();
            $this->user_list = InspectionStaff::query()->select();
            $this->fetch();
        }
    }
}